Package: simcross
Version: 0.10
Date: 2026-06-08
Title: Simulate Experimental Crosses
Description: Simulate and plot general experimental crosses. The focus is on simulating genotypes with an aim towards flexibility rather than speed. Meiosis is simulated following the Stahl model, in which chiasma locations are the superposition of two processes: a proportion p coming from a process exhibiting no interference, and the remainder coming from a process following the chi-square model.
Author: Karl W Broman [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4914-6671>)
Maintainer: Karl W Broman <broman@wisc.edu>
Authors@R: c(person("Karl W", "Broman", role=c("aut", "cre"),
             email="broman@wisc.edu", comment=c(ORCID = "0000-0002-4914-6671")))
Depends: R (>= 3.1.0)
Imports: graphics, stats, Rcpp (>= 0.12.17)
Suggests: qtl, knitr, rmarkdown, testthat, devtools, roxygen2
License: GPL-3
URL: https://kbroman.org/simcross/, https://github.com/kbroman/simcross
BugReports: https://github.com/kbroman/simcross/issues
VignetteBuilder: knitr
LinkingTo: Rcpp
LazyData: true
Encoding: UTF-8
ByteCompile: true
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-06-09 02:55:46 UTC; kbroman
Repository: CRAN
Date/Publication: 2026-06-09 03:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-06-09 06:46:41 UTC; unix
Archs: simcross.so.dSYM
