# Generated by roxygen2: do not edit by hand

export(CCcolors)
export(calc_Lstar)
export(check_pedigree)
export(collapse_do_alleles)
export(convert2geno)
export(convert2geno_allchr)
export(create_parent)
export(cross)
export(get_geno)
export(plot_crosslines)
export(plot_ind)
export(sim_4way_pedigree)
export(sim_ail_pedigree)
export(sim_ail_pedigree_fix_n)
export(sim_crossovers)
export(sim_do_pedigree)
export(sim_do_pedigree_fix_n)
export(sim_dof1_pedigree)
export(sim_from_pedigree)
export(sim_from_pedigree_allchr)
export(sim_meiosis)
export(sim_ril_pedigree)
export(where_het)
importFrom(Rcpp,sourceCpp)
importFrom(grDevices,rgb)
importFrom(graphics,arrows)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,rect)
importFrom(graphics,segments)
importFrom(stats,dpois)
importFrom(stats,uniroot)
useDynLib(simcross, .registration=TRUE)
